==> nextcloud-20.0.12.tgz: nextcloud/apps/weather_status/l10n/he.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "כתובת לא ידועה",
    "No result." : "אין תוצאות.",
    "Malformed JSON data." : "נתוני JSON פגומים.",
    "Error" : "שגיאה",
    "Weather status" : "מצב מזג אוויר",
    "Weather status in your dashboard" : "מצב מזג אוויר בלוח המחוונים שלך.",
    "Detect location" : "איתור מיקום",
    "Set custom address" : "הגדרת כתובת משלך",
    "Favorites" : "מועדפים",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} שמיים בהירים ב־{time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} מעונן ב־{time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} יום נוח ב־{time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} לילה נוח ב־{time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} מעונן חלקית ב־{time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} ערפילי ב־{time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} טפטוף קל ב־{time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} גשם ב־{time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} גשם כבד ב־{time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} ממטרים ב־{time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} ממטרים קלים ב־{time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} ממטרים כבדים ב־{time}",
    "More weather for {adr}" : "מזג אוויר נוסף עבור {adr}",
    "Loading weather" : "מזג האוויר נטען",
    "Set location for weather" : "הגדרת מיקום למזג האוויר",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add as favorite" : "הוספה למועדפים",
    "You are not logged in." : "לא נכנסת.",
    "There was an error getting the weather status information." : "אירעה שגיאה בקבלת פרטי מצב מזג האוויר.",
    "No weather information found" : "לא נמצאו פרטי מזג אוויר",
    "Location not found" : "המיקום לא נמצא",
    "There was an error setting the location address." : "אירעה שגיאה בהגדרות כתובת המיקום.",
    "There was an error setting the location." : "אירעה שגיאה בהגדרת המיקום.",
    "There was an error saving the mode." : "אירעה שגיאה בשמירת המצב.",
    "There was an error using personal address." : "אירעה שגיאה בשימוש בכתובת האישית."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-23.0.8.tgz: nextcloud/apps/weather_status/l10n/he.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "כתובת לא ידועה",
    "No result." : "אין תוצאות.",
    "Malformed JSON data." : "נתוני JSON פגומים.",
    "Error" : "שגיאה",
    "Weather status" : "מצב מזג אוויר",
    "Weather status in your dashboard" : "מצב מזג אוויר בלוח המחוונים שלך.",
    "Detect location" : "איתור מיקום",
    "Set custom address" : "הגדרת כתובת משלך",
    "Favorites" : "מועדפים",
    "More weather for {adr}" : "מזג אוויר נוסף עבור {adr}",
    "Loading weather" : "מזג האוויר נטען",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add as favorite" : "הוספה למועדפים",
    "You are not logged in." : "לא נכנסת.",
    "There was an error getting the weather status information." : "אירעה שגיאה בקבלת פרטי מצב מזג האוויר.",
    "No weather information found" : "לא נמצאו פרטי מזג אוויר",
    "Location not found" : "המיקום לא נמצא",
    "There was an error setting the location address." : "אירעה שגיאה בהגדרות כתובת המיקום.",
    "There was an error setting the location." : "אירעה שגיאה בהגדרת המיקום.",
    "There was an error saving the mode." : "אירעה שגיאה בשמירת המצב.",
    "There was an error using personal address." : "אירעה שגיאה בשימוש בכתובת האישית.",
    "Set location for weather" : "הגדרת מיקום למזג האוויר",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} שמיים בהירים ב־{time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} מעונן ב־{time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} יום נוח ב־{time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} לילה נוח ב־{time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} מעונן חלקית ב־{time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} ערפילי ב־{time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} טפטוף קל ב־{time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} גשם ב־{time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} גשם כבד ב־{time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} ממטרים ב־{time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} ממטרים קלים ב־{time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} ממטרים כבדים ב־{time}"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
